package Cpanel::Easy::ModGeoIP;

# Special thanks to Sohail Riaz (http://www.sohailriaz.com/) for his nice work creating this opt mod initially!

our $easyconfig = {
    'name'     => 'Mod GeoIP',
    'url'      => 'http://www.maxmind.com/app/mod_geoip',
    'note'     => 'mod_geoip v1.2.5 for Apache 2.x',
    'hastargz' => 1,
    'src_cd2'  => 'mod_geoip2_1.2.5/',
    'modself'  => sub {
        my ( $easy, $self_hr, $profile_hr ) = @_;
        if ( $easy->get_ns_value_from_profile( 'Cpanel::Easy::Apache::1', $profile_hr ) eq '1' ) {
            $self_hr->{'note'}      = 'mod_geoip v1.3.4 for Apache 1.3';
            $self_hr->{'src_cd2'}   = 'mod_geoip_1.3.4/';
            $self_hr->{'step'}{'1'} = {
                'name'    => 'Adding /opt/geoip/lib to ld.so.conf, required for Apache 1.3',
                'command' => sub {
                    my ($self) = @_;
                    my $ld_so_conf_entry_exists = 0;
                    
                    if (open my $ld_conf_rfh, '<', '/etc/ld.so.conf') {
                        while (my $line = readline($ld_conf_rfh)) {
                            if( $line =~ m{^\s*\/opt\/geoip\/lib\s*$}) {
                                $ld_so_conf_entry_exists = 1;
                                last;
                            }
                        }   
                        close $ld_conf_rfh;
                    }
                    else {
                        $self->print_alert_color( 'red', q{Could not open '[_1]' for reading: [_2]}, '/etc/ld.so.conf', $!);
                        $self->print_alert_color( 'red', q{You will need to add '[_1]' to '[_2]' manually!}, '/opt/geoip/lib\n', '/etc/ld.so.conf');
                        return(1,'ok');
                    }
                    if ($ld_so_conf_entry_exists) {
                        $self->print_alert(q{'[_1]' already has '[_2]'}, '/etc/ld.so.conf', '/opt/geoip/lib\n');
                        return (1,'ok');
                    }

                    $self->print_alert(q{Adding '[_1]' to '[_2]'}, '/opt/geoip/lib\n', '/etc/ld.so.conf');
                    
                    if (open my $ld_conf_afh, '>>', '/etc/ld.so.conf') {
                        print {$ld_conf_afh} "/opt/geoip/lib\n";               
                        close $ld_conf_afh;
                    }
                    else {
                        $self->print_alert_color( 'red', q{Could not open '[_1]' for appending: [_2]}, '/etc/ld.so.conf', $!);
                        $self->print_alert_color( 'red', q{You will need to add '[_1]' to '[_2]' manually!}, '/opt/geoip/lib\n', '/etc/ld.so.conf');
                        return(1,'ok');
                    }
                    return $self->run_system_cmd_returnable([qw(/sbin/ldconfig /etc/ld.so.conf)]);
                },
            };
        }
    },
    'step' => {
        '0' => {
            'name'    => 'Installing GeoIP C Library',
            'command' => sub {
                my ($self) = @_;
                my ( $path, @text ) = $self->get_path_installed('Cpanel::Easy::OptLib::geoip');
                if ($path) {
                    $self->{'__'}{'GeoIPPath'} = $path;
                    return ( 1, 'Ok' );
                }
                else {
                    return $path, @text;
                }
            },
        },

        # no need for '1', see 'modself'
        '2' => {
            'name'    => 'APXSing mod_geoip into apache',
            'command' => sub {
                my ($self) = @_;
                return $self->run_system_cmd_returnable( [ $self->_get_main_apxs_bin(), qw(-i -a -L/opt/geoip/lib -I/opt/geoip/include -lGeoIP -c mod_geoip.c) ] );
            },
        },
    },
};

1;
